summaryrefslogtreecommitdiff
path: root/compiler/GHC/Core/TyCon.hs
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/GHC/Core/TyCon.hs')
-rw-r--r--compiler/GHC/Core/TyCon.hs4
1 files changed, 2 insertions, 2 deletions
diff --git a/compiler/GHC/Core/TyCon.hs b/compiler/GHC/Core/TyCon.hs
index ad455779b7..9982436429 100644
--- a/compiler/GHC/Core/TyCon.hs
+++ b/compiler/GHC/Core/TyCon.hs
@@ -224,8 +224,8 @@ See also Note [Wrappers for data instance tycons] in GHC.Types.Id.Make
* Reply "yes" to isDataFamilyTyCon, and isFamilyTyCon
-* The user does not see any "equivalent types" as he did with type
- synonym families. He just sees constructors with types
+* The user does not see any "equivalent types" as they did with type
+ synonym families. They just see constructors with types
T1 :: T Int
T2 :: Bool -> T Int